This module provides support for Views, which provide a
reference-mapping functionality to support simple, zero-copy
use cases, which require a mapping of head values.
This is especially useful if the mapping itself either has
only a rather small overhead or the resulting View is only
traversed once.
Structs
Traits
- ViewFn
- helper trait to create namable closures